@@ -17,10 +17,9 @@
  * the License.
  */
 
-// Note: these tests assume the existence of some well-known directories and
-// devices: /mnt, /home, /tmp, and /dev/loop0.  This is because the mountpoint
-// loading code only retains mountpoints on valid directories, and only retains
-// device names for valid device nodes.
+// Note: these tests assume the existence of some well-known directories: /mnt,
+// /home, and /tmp.  This is because the mountpoint loading code only retains
+// mountpoints on valid directories.
 
 package filesystem
 
@@ -28,6 +27,7 @@ import (
 	"fmt"
 	"os"
 	"path/filepath"
+	"reflect"
 	"strings"
 	"testing"
 )
@@ -100,6 +100,11 @@ func TestLoadMountInfoBasic(t *testing.T) {
 // Test that Mount.Device is set to the mountpoint's source device if
 // applicable, otherwise it is set to the empty string.
 func TestLoadSourceDevice(t *testing.T) {
+	// The mountinfo parser ignores devices that don't exist.  For the valid
+	// device, try /dev/loop0.  If it doesn't exist, skip the test.
+	if _, err := os.Stat("/dev/loop0"); err != nil {
+		t.Skip("/dev/loop0 does not exist, skipping test")
+	}
 	var mountinfo = `
 15 0 7:0 / / rw shared:1 - foo /dev/loop0 rw,data=ordered
 31 15 0:27 / /tmp rw,nosuid,nodev shared:17 - tmpfs tmpfs rw
@@ -540,3 +545,21 @@ func BenchmarkLoadFirst(b *testing.B) {
 		}
 	}
 }
+
+// Test mount comparison by values instead of by reference,
+// as the map mountsByDevice gets recreated on each load.
+// This ensures that concurrent mounts work properly.
+func TestMountComparison(t *testing.T) {
+	var mountinfo = `
+15 0 259:3 / /home rw,relatime shared:1 - ext4 /dev/root rw,data=ordered
+`
+	beginLoadMountInfoTest()
+	defer endLoadMountInfoTest()
+	loadMountInfoFromString(mountinfo)
+	firstMnt := mountForDevice("259:3")
+	loadMountInfoFromString(mountinfo)
+	secondMnt := mountForDevice("259:3")
+	if !reflect.DeepEqual(firstMnt, secondMnt) {
+		t.Errorf("Mount comparison does not work")
+	}
+}
